aboutsummaryrefslogtreecommitdiffstats
path: root/java/src
diff options
context:
space:
mode:
authorJean Chalard <jchalard@google.com>2012-05-17 01:15:02 -0700
committerAndroid (Google) Code Review <android-gerrit@google.com>2012-05-17 01:15:02 -0700
commit71b047e3018555690ec3e4a639b395f1f79e1e67 (patch)
tree559b931666395b4e2d7b7fd773cb4600a92f10c9 /java/src
parenta1500959b657f3100914e2cf34f4aeb5d2e68c82 (diff)
parent125de3dfdf548359de890247907f2e6f430008ec (diff)
downloadlatinime-71b047e3018555690ec3e4a639b395f1f79e1e67.tar.gz
latinime-71b047e3018555690ec3e4a639b395f1f79e1e67.tar.xz
latinime-71b047e3018555690ec3e4a639b395f1f79e1e67.zip
Merge "Don't deactivate the LastComposedWord on shift" into jb-dev
Diffstat (limited to 'java/src')
-rw-r--r--java/src/com/android/inputmethod/latin/LatinIME.java5
1 files changed, 3 insertions, 2 deletions
diff --git a/java/src/com/android/inputmethod/latin/LatinIME.java b/java/src/com/android/inputmethod/latin/LatinIME.java
index b59e939b7..261755f53 100644
--- a/java/src/com/android/inputmethod/latin/LatinIME.java
+++ b/java/src/com/android/inputmethod/latin/LatinIME.java
@@ -1298,8 +1298,9 @@ public class LatinIME extends InputMethodService implements KeyboardActionListen
break;
}
switcher.onCodeInput(primaryCode);
- // Reset after any single keystroke
- if (!didAutoCorrect)
+ // Reset after any single keystroke, except shift and symbol-shift
+ if (!didAutoCorrect && primaryCode != Keyboard.CODE_SHIFT
+ && primaryCode != Keyboard.CODE_SWITCH_ALPHA_SYMBOL)
mLastComposedWord.deactivate();
mEnteredText = null;
}